@@ -13,13 +13,11 @@ class OrderController
 
     public function __construct($pluginDirectoryPath, $pluginDirectoryURL)
     {
-
         $this->pluginDirectoryPath = $pluginDirectoryPath;
         $this->pluginDirectoryURL = $pluginDirectoryURL;
 
         $this->registerActions();
         $this->registerFilters();
-
     }
 
     private function registerActions()
@@ -81,7 +79,6 @@ class OrderController
                 'callback' => [$this, 'getAllOrdersForPrint'],
             ]);
         });
-
     }
 
     private function registerFilters()
@@ -91,21 +88,52 @@ class OrderController
 
     public static function getOrders($orderTypes)
     {
-        if (class_exists('WC_Order_Query')) {
-            $query = new \WC_Order_Query([
-                'limit' => -1,
-                'orderby' => 'date',
-                'order' => 'ASC',
-            ]);
-            $orders = $query->get_orders();
-
-        }
-
         if ($orderTypes == 'currentOrders') {
+            if (class_exists('WC_Order_Query')) {
+                $query = new \WC_Order_Query([
+                    'limit' => -1,
+                    'orderby' => 'date',
+                    'order' => 'ASC',
+                    'status' => ['wc-processing', 'wc-awaiting', 'wc-order-started', 'wc-being-collated', 'wc-ready', 'wc-datechanged', 'wc-readyfordelivery']
+                    //'status' => ['wc-processing', 'wc-awaiting', 'wc-order-started', 'wc-being-collated', 'wc-ready', 'wc-collected', 'wc-cancelled', 'wc-notcollected', 'wc-datechanged', 'wc-readyfordelivery']
+                ]);
+                $orders = $query->get_orders();
+            }
+
             $orderData = self::getOrderDataAsJson($orders);
         } else {
-            $orderData = self::getPastOrderDataAsJson($orders);
+            $dateTwoWeeksAgo = date('Y-m-d', strtotime("-2 weeks"));
+            $dateToday = date("Y-m-d");
 
+            function displayDates($date1, $date2, $format = 'Y-m-d')
+            {
+                $dates = [];
+                $current = strtotime($date1);
+                $date2 = strtotime($date2);
+                $stepVal = '+1 day';
+                while ($current <= $date2) {
+                    $dates[] = date($format, $current);
+                    $current = strtotime($stepVal, $current);
+                }
+                return $dates;
+            }
+
+            $dates = displayDates($dateTwoWeeksAgo, $dateToday);
+
+            global $wpdb;
+            $wooOrders = [];
+
+            foreach ($dates as $date) {
+                $getOrdersSQL = 'SELECT id FROM pex_simonhowie_posts WHERE id IN (SELECT order_id FROM pex_simonhowie_woocommerce_order_items WHERE order_item_id IN (SELECT order_item_id FROM pex_simonhowie_woocommerce_order_itemmeta WHERE meta_key = "_pickup_date" AND meta_value = "'. $date .'"))';
+                
+                $resultsGetOrders = $wpdb->get_results($getOrdersSQL);
+
+                foreach ($resultsGetOrders as $wooOrder) {
+                    array_push($wooOrders, wc_get_order($wooOrder->id));
+                }
+            }
+
+            $orderData = self::getPastOrderDataAsJson($wooOrders);
         }
 
         return $orderData;
@@ -115,7 +143,6 @@ class OrderController
     {
         $days = [];
         foreach ($orders as $singleOrder) {
-
             if ($_GET['location'] === strtolower(self::getShippingDetails($singleOrder)['Pickup Location'])) {
                 $pickupDate = self::getShippingDetails($singleOrder)['Pickup Date'];
                 $pickupDate = strtotime($pickupDate);
@@ -124,7 +151,6 @@ class OrderController
                 $order = new Order($singleOrder);
 
                 if ($order->getOrderStatus() != "6" && $order->getOrderStatus() != "7" && $order->getOrderStatus() != "8") {
-
                     if (!isset($days[$pickupDate])) {
                         $days[$pickupDate] = [
                             'date' => $newDate,
@@ -134,7 +160,6 @@ class OrderController
 
                     $days[$pickupDate]['orders'][] = $order->newOrderData();
                 }
-
             }
         }
 
@@ -147,22 +172,23 @@ class OrderController
      */
     public static function getShippingDetails($order)
     {
-
         $shippingDataArray = [];
-        foreach ($order->get_items('shipping') as $itemId => $shippingObject) {
-            $shippingData = $shippingObject->get_data();
-            foreach ($shippingData['meta_data'] as $singleShippingData) {
-                $singleShippingData = $singleShippingData->get_data();
-                switch ($singleShippingData['key']) {
-                    case '_pickup_location_name':
-                        $shippingDataArray['Pickup Location'] = $singleShippingData['value'];
-                        break;
-                    case '_pickup_date':
-                        $shippingDataArray['Pickup Date'] = $singleShippingData['value'];
-                        break;
-                    case '_pickup_location_address':
-                        $shippingDataArray['Pickup address'] = $singleShippingData['value'];
-                        break;
+        if ($order) {
+            foreach ($order->get_items('shipping') as $itemId => $shippingObject) {
+                $shippingData = $shippingObject->get_data();
+                foreach ($shippingData['meta_data'] as $singleShippingData) {
+                    $singleShippingData = $singleShippingData->get_data();
+                    switch ($singleShippingData['key']) {
+                        case '_pickup_location_name':
+                            $shippingDataArray['Pickup Location'] = $singleShippingData['value'];
+                            break;
+                        case '_pickup_date':
+                            $shippingDataArray['Pickup Date'] = $singleShippingData['value'];
+                            break;
+                        case '_pickup_location_address':
+                            $shippingDataArray['Pickup address'] = $singleShippingData['value'];
+                            break;
+                    }
                 }
             }
         }
@@ -172,9 +198,8 @@ class OrderController
     public static function getPastOrderDataAsJson($orders)
     {
         $days = [];
+
         foreach ($orders as $singleOrder) {
-
-
             if ($_GET['location'] === strtolower(self::getShippingDetails($singleOrder)['Pickup Location'])) {
                 $pickupDate = self::getShippingDetails($singleOrder)['Pickup Date'];
                 $pickupDate = strtotime($pickupDate);
@@ -189,8 +214,7 @@ class OrderController
                     ];
                 }
 
-                $days[$pickupDate]['orders'][] = $order->newOrderData();
-
+                $days[$pickupDate]['orders'][] = $order->newPastOrderData();
             }
         }
 
@@ -242,7 +266,6 @@ class OrderController
     {
         $days = [];
         foreach ($orders as $singleOrder) {
-
             if ($_GET['location'] === strtolower(self::getShippingDetails($singleOrder)['Pickup Location'])) {
                 $pickupDate = self::getShippingDetails($singleOrder)['Pickup Date'];
                 $pickupDate = strtotime($pickupDate);
@@ -257,7 +280,6 @@ class OrderController
                     ];
                 }
                 $days[$pickupDate]['orders'][] = $order->newOrderData();
-
             }
         }
 
@@ -266,7 +288,6 @@ class OrderController
 
     public static function viewOrders($data)
     {
-
         $orderId = $data->get_params()['id'];
         $order = wc_get_order($orderId);
 
@@ -305,10 +326,8 @@ class OrderController
             } else {
                 $couponArray['amount'] = '£' . $couponObject->get_amount();
             }
-
         }
         return $couponArray;
-
     }
 
 
@@ -320,19 +339,16 @@ class OrderController
         if (!add_post_meta($orderNumber, 'shop_id', $shopNumber, true)) {
             update_post_meta($orderNumber, 'shop_id', $shopNumber);
         }
-
     }
 
     public static function setFinalPrice($data)
     {
-
         $finalPrice = $data->get_params()['formValues'];
         $orderNumber = json_decode($data->get_params()['id'])->row;
 
         if (!add_post_meta($orderNumber, 'final_price', $finalPrice, true)) {
             update_post_meta($orderNumber, 'final_price', $finalPrice);
         }
-
     }
 
     public static function setOrderStatus($data)
@@ -401,9 +417,11 @@ class OrderController
                 $successMessage = 'Order has been marked as Ready for Delivery';
             }
         }
-
+        if ($statusNumber == 11) {
+            $order->update_status('wc-completed');
+            $successMessage = 'Order has been marked as completed';
+        }
         return $successMessage;
-
     }
 
     public function emailCustomerOrder($shopNumber, $order)
@@ -436,7 +454,6 @@ class OrderController
 
     public function emailCustomerThankYou($order)
     {
-
         $order = new Order($order);
 
         $to = $order->getEmail();
@@ -449,14 +466,23 @@ class OrderController
         $headers = ['Content-Type: text/html; charset=UTF-8'];
 
         wp_mail($to, $subject, $message, $headers);
-
     }
 
     public function emailCustomerReadyForDelivery($order)
     {
-
+        $shipping = self::getShippingDetails($order);
         $order = new Order($order);
 
+        $finalPrice = $order->getFinalPrice();
+        $orderItems = [];
+
+        foreach ($order->getOrderItems() as $itemKey => $item) {
+            $newOrderItem = new OrderItem($item, $itemKey, $order->getOrderID());
+            $orderItems[] = $newOrderItem->newOrderItemData();
+        };
+
+        $date = strtotime($shipping['Pickup Date']);
+
         $to = $order->getEmail();
         $subject = 'Your Simon Howie order is now ready for delivery.';
         $template = 'delivery';
@@ -467,7 +493,6 @@ class OrderController
         $headers = ['Content-Type: text/html; charset=UTF-8'];
 
         wp_mail($to, $subject, $message, $headers);
-
     }
 
 
@@ -537,7 +562,6 @@ class OrderController
             'show_in_admin_status_list' => true,
             'label_count' => _n_noop('Ready for Delivery <span class="count">(%s)</span>', 'Ready for Delivery <span class="count">(%s)</span>'),
         ]);
-
     }
 
     public static function getNotes($data)
@@ -565,7 +589,6 @@ class OrderController
         }
 
         return $orderNotes;
-
     }
 
     public static function addNote($data)
@@ -625,7 +648,6 @@ class OrderController
         $orderItems = [];
 
         foreach ($orderObject->getOrderItems() as $itemKey => $item) {
-
             $newOrderItem = new OrderItem($item, $itemKey, $orderId);
             $orderItems[] = $newOrderItem->newOrderItemData();
         };
@@ -654,7 +676,6 @@ class OrderController
 
     public static function orderDataForPrint($orders, $location, $date, $status)
     {
-
         $orderData = [];
         foreach ($orders as $singleOrder) {
             $pickupDate = self::getShippingDetails($singleOrder)['Pickup Date'];
@@ -672,7 +693,6 @@ class OrderController
                 }
 
                 if (!in_array($order->getOrderStatus(), $statuses)) {
-
                     if (!isset($orderData[$orderId])) {
                         $coupons = self::getCoupons($orderId);
 
@@ -703,12 +723,12 @@ class OrderController
         return $orderData;
     }
 
-    function dateSort($a, $b)
+    public function dateSort($a, $b)
     {
         return strtotime($a) - strtotime($b);
     }
 
-    function addToWoocommerceOrderStatus($orderStatuses)
+    public function addToWoocommerceOrderStatus($orderStatuses)
     {
         $newOrderStatuses = [];
         foreach ($orderStatuses as $key => $status) {
@@ -722,9 +742,9 @@ class OrderController
                 $newOrderStatuses['wc-notcollected'] = 'Not Collected';
                 $newOrderStatuses['wc-datechanged'] = 'Collection Date Changed';
                 $newOrderStatuses['wc-readyfordelivery'] = 'Ready for Delivery';
+                $newOrderStatuses['wc-completed'] = 'Completed';
             }
         }
         return $newOrderStatuses;
     }
-
-}
\ No newline at end of file
+}
